pub struct AclBinding {
pub resource_type: i8,
pub resource_name: String,
pub pattern_type: i8,
pub principal: String,
pub host: String,
pub operation: i8,
pub permission: i8,
}Expand description
One ACL binding for CreateAcls / DescribeAcls.
Fields
resource_type: i8Kafka resource type (ACL_RESOURCE_TOPIC, AclResourceType::Topic, …).
resource_name: StringResource name (topic name, …).
pattern_type: i8Pattern type (ACL_PATTERN_LITERAL, AclPatternType::Literal, …).
Omitted on the wire at v0; decode fills LITERAL.
principal: StringPrincipal, for example User:alice.
host: StringHost filter (* is any).
operation: i8Operation (ACL_OPERATION_ALL, AclOperation::All, …).
permission: i8Permission (ACL_PERMISSION_ALLOW, AclPermission::Allow, …).
Implementations
Sourceimpl AclBinding
impl AclBinding
Sourcepub fn allow(
resource_type: impl Into<i8>,
name: impl Into<String>,
principal: impl Into<String>,
) -> Self
pub fn allow( resource_type: impl Into<i8>, name: impl Into<String>, principal: impl Into<String>, ) -> Self
Allow every operation on name for principal from any host.
Sourcepub fn allow_topic(
topic: impl Into<String>,
principal: impl Into<String>,
) -> Self
pub fn allow_topic( topic: impl Into<String>, principal: impl Into<String>, ) -> Self
Allow every operation on topic for principal from any host.
Sourcepub fn pattern_type(self, pattern_type: impl Into<i8>) -> Self
pub fn pattern_type(self, pattern_type: impl Into<i8>) -> Self
Resource pattern type (AclPatternType::Literal, …).
Sourcepub fn permission(self, permission: impl Into<i8>) -> Self
pub fn permission(self, permission: impl Into<i8>) -> Self
Permission (AclPermission::Allow, …).
Sourcepub fn new(pattern: ResourcePattern, entry: AccessControlEntry) -> Self
pub fn new(pattern: ResourcePattern, entry: AccessControlEntry) -> Self
Java AclBinding(ResourcePattern, AccessControlEntry).
Sourcepub fn pattern(&self) -> ResourcePattern
pub fn pattern(&self) -> ResourcePattern
Java AclBinding.pattern.
Sourcepub fn entry(&self) -> AccessControlEntry
pub fn entry(&self) -> AccessControlEntry
Java AclBinding.entry.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Java AclBinding.isUnknown.
Sourcepub fn to_filter(&self) -> AclBindingFilter
pub fn to_filter(&self) -> AclBindingFilter
Java AclBinding.toFilter.